@@ -21,7 +21,10 @@
 #include "apr_strings.h"
 #include "apr_queue.h"
 #include "apr_global_mutex.h"
+#include "apr_version.h"
+#if APR_MAJOR_VERSION < 2
 #include "apr_support.h"
+#endif
 #include "http_config.h"
 #include "fcgid_pm.h"
 #include "fcgid_pm_main.h"
@@ -138,7 +141,7 @@ static void fcgid_maint(int reason, void *data, apr_wait_t status)
                  * try to terminate httpd
                  */
                 kill(getpid(), SIGTERM);
-                
+
             }
             else {
                 ap_log_error(APLOG_MARK, APLOG_ERR, 0, NULL,
@@ -352,9 +355,9 @@ procmgr_post_config(server_rec * main_server, apr_pool_t * configpool)
                                                     &fcgid_module);
 
     /* Calculate procmgr_peek_cmd wake up interval */
-    g_wakeup_timeout = fcgid_min(sconf->error_scan_interval, 
+    g_wakeup_timeout = fcgid_min(sconf->error_scan_interval,
                                  sconf->busy_scan_interval);
-    g_wakeup_timeout = fcgid_min(sconf->idle_scan_interval, 
+    g_wakeup_timeout = fcgid_min(sconf->idle_scan_interval,
                                  g_wakeup_timeout);
     if (g_wakeup_timeout == 0)
         g_wakeup_timeout = 1;   /* Make it reasonable */
@@ -522,7 +525,11 @@ apr_status_t procmgr_peek_cmd(fcgid_command * command,
         return APR_EPIPE;
 
     /* Wait for next command */
+#if APR_MAJOR_VERSION < 2
     rv = apr_wait_for_io_or_timeout(g_pm_read_pipe, NULL, FOR_READ);
+#else
+    rv = apr_file_pipe_wait(g_pm_read_pipe, APR_WAIT_READ);
+#endif
 
     /* Log any unexpect result */
     if (rv != APR_SUCCESS && !APR_STATUS_IS_TIMEUP(rv)) {
